package models

import (
	"time"

	"github.com/beego/beego/v2/client/orm"
)

type SysUser struct {
	SysUserId         int       `orm:"pk" description:"系统用户id"`
	SysUserName       string    `description:"账号"`
	SysRealName       string    `description:"姓名"`
	Password          string    `description:"密码"`
	Email             string    `description:"邮箱"`
	Phone             string    `description:"手机号"`
	AreaCode          string    `description:"手机区号"`
	SysRoleId         int       `description:"角色id"`
	SysRoleName       string    `description:"角色名称"`
	SysDepartmentId   int       `description:"所属部门id"`
	SysDepartmentName string    `description:"所属部门全路径"`
	Province          string    `description:"省"`
	City              string    `description:"市"`
	IsEnabled         bool      `description:"是否启用"`
	CreateTime        time.Time `description:"创建时间"`
	ModifyTime        time.Time `description:"更新时间"`
}

func (s *SysUser) Save() (err error) {
	o := orm.NewOrmUsingDB("master")
	_, err = o.InsertOrUpdate(s, "sys_user_id")
	return
}

func (s *SysUser) Update(cols []string) (err error) {
	o := orm.NewOrmUsingDB("master")
	_, err = o.Update(s, cols...)
	return
}

func GetSysUserBySysUserName(sysUserName string) (item *SysUser, err error) {
	sql := `SELECT * FROM sys_user WHERE sys_user_name=?`
	o := orm.NewOrmUsingDB("master")
	err = o.Raw(sql, sysUserName).QueryRow(&item)
	return
}

func GetSysUserById(sysUserId int) (item *SysUser, err error) {
	sql := `SELECT * FROM sys_user WHERE sys_user_id=?`
	o := orm.NewOrmUsingDB("master")
	err = o.Raw(sql, sysUserId).QueryRow(&item)
	return
}

func GetSysUserCountBySysUserName(sysUserName string) (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM sys_user WHERE sys_user_name=?`
	o := orm.NewOrmUsingDB("master")
	err = o.Raw(sql, sysUserName).QueryRow(&count)
	return
}

func GetSysUserCount() (count int, err error) {
	sql := `SELECT COUNT(1) AS count FROM sys_user`
	o := orm.NewOrmUsingDB("master")
	err = o.Raw(sql).QueryRow(&count)
	return
}

func GetSysUserList(startSize, pageSize int) (items []*SysUser, err error) {
	sql := `SELECT * FROM sys_user ORDER BY modify_time DESC LIMIT ?,?`
	o := orm.NewOrmUsingDB("master")
	_, err = o.Raw(sql, startSize, pageSize).QueryRows(&items)
	return
}
